MacroAttribute

Struct MacroAttribute 

pub struct MacroAttribute { /* private fields */ }
Represents a macro attribute and its arguments like:

#[attribute(key="value")]

Implementations

Source

impl MacroAttribute

pub fn new(attribute: Attribute) -> Result<Self>

Constructs a new MacroAttribute from an Attribute.

pub fn from_attribute_args( path: &str, attribute_args: AttributeArgs, style: AttrStyle, ) -> Self

Constructs a MacroAttribute from an AttributeArgs.

pub fn path(&self) -> &str

Returns the path of an attribute.

For #[attribute(name="value")] the path is "attribute".

pub fn style(&self) -> Option<&AttrStyle>

Returns the style of this attribute: outer or inner.

pub fn args(&self) -> &[MetaItem]

Returns the arguments of the attribute.

For #[attribute(name="value", number=10)] the arguments are "name=value" and "number=10".

pub fn len(&self) -> usize

Returns the number of arguments in this attribute.

pub fn is_empty(&self) -> bool

Returns true is this macro attribute have no arguments.

pub fn get(&self, index: usize) -> Option<&MetaItem>

Returns the MetaItem in the given index, or None if not found.

pub fn iter(&self) -> impl Iterator<Item = &MetaItem>

Returns an iterator over the arguments in this attribute.

pub fn into_name_values(self) -> Result<NameValueAttribute, NameValueError>

Converts this macro attribute into a name-value attribute.

pub fn into_inner(self) -> Vec<MetaItem>

Converts this macro attribute into a list of its arguments.